@@ -178,14 +178,15 @@ def get_caller_locals(depth: int):
 
 
 class ErrorBase(Exception):
-    extra = {}
+    code = 3
+
+    def __init__(self, message: str, error_key: str = None):
+        super().__init__(message)
+        self.error_key = error_key or self.__class__.__name__
 
     @property
-    def error_key(self):
-        try:
-            return str(self.args[1])
-        except IndexError:
-            return self.__class__.__name__
+    def message(self) -> str:
+        return self.args[0]
 
     def __str__(self):
         if not self.args:
@@ -193,19 +194,15 @@ class ErrorBase(Exception):
         return str(self.args[0])
 
     def to_dict(self):
-        if len(self.args) > 2 and isinstance(self.args[2], dict):
-            return self.args[2]
-        dic = {'message': str(self), 'error_key': self.error_key}
-        dic.update(self.extra)
-        return dic
+        return {
+            'code': self.code,
+            'data': self.error_key,
+            'message': self.message,
+        }
 
     @classmethod
     def from_dict(cls, dic: dict):
-        return cls(
-            dic.get('message', ''),
-            dic.get('error_key', cls.__name__),
-            dic,
-        )
+        return cls(dic['message'], dic.get('data', cls.__name__))
 
 
 class ErrorInfo:
@@ -274,7 +271,7 @@ class ErrorInfo:
             return self.exc.to_dict()
         return {
             'code': code,
-            'error_key': self.error_key,
+            'data': {'error_key': self.error_key},
             'message': f'{self.message} <{self.error_key}>',
         }
 
